<?php

/**
 * Class SGC_Admin_Events
 * All class methods for creating the custom post type sgc_event
 * 
 * @author Matthew Linton
 *
 */
class SGC_Admin_Events {

    /**
     * 
     */
    public function create_post_type_events() {
        $labels = array(
            'name' => 'Events',
            'singular_name' => 'Event',
            'add_new' => 'Add New Event',
            'add_new_item' => 'Add New Event',
            'edit_item' => 'Edit Event',
            'new_item' => 'New Event',
            'all_items' => 'All Events',
            'view_item' => 'View Event',
            'search_items' => 'Search Events',
            'not_found' => 'No Events Found',
            'not_found_in_trash' => 'No Events found in Trash',
            'parent_item_colon' => '',
            'menu_name' => 'Events'
        );

        register_post_type('sgc_event', array(
            'labels' => $labels,
            'has_archive' => true,
            'public' => true,
            'show_in_rest' => true,
            'rest_base' => 'sgc_events',
            'supports' => array('title', 'editor', 'thumbnail', 'comments'),
            'taxonomies' => array(''),
            'exclude_from_search' => false,
            'capability_type' => 'post',
            'rewrite' => array('slug' => 'sgc_events'),
            'menu_icon' => 'dashicons-tickets-alt'
        ));
    }

    /**
     * 
     */
    public function add_event_fields($posts) {
        add_meta_box(
                'sgc_custom_event_fields', 
                __('Event Details'), 
                array('SGC_Admin_Events', 'event_fields_html'), 
                'sgc_event', 
                'side'
        );
    }

    /**
     * 
     */
    public function event_fields_html($posts) {
        global $wpdb, $post;

        $default_team = get_option('sgc_defaultteam');
        $default_location = get_option('sgc_defaultlocation');

        $event_date = get_post_meta($post->ID, 'sgc_eventdate', true);
        $event_time = get_post_meta($post->ID, 'sgc_eventtime', true);
        $event_location = get_post_meta($post->ID, 'sgc_eventlocation', true);
        $event_tee = get_post_meta($post->ID, 'sgc_eventtee', true);
        $event_team = get_post_meta($post->ID, 'sgc_eventteam', true);
        $event_groups = get_post_meta($post->ID, 'sgc_eventgroups', true);
        $event_checkedin = get_post_meta($post->ID, 'sgc_eventcheckin', true);

        if (!$event_team || $event_team == '') {
            $event_team = $default_team;
        }

        if (!$event_location || $event_location == '') {
            $event_location = $default_location;
        }

        if (!$event_tee || $event_tee == '') {
            $event_tee = __('Any Tee');
        }
        
        // Fetch list of tees for this location
        $tees = [];
        if ( $event_location != '' ) {
            $tees = json_decode( get_post_meta($event_location, 'sgc_locationcourse', true) );
        }
        
        // fetch all locations list
        $locations = get_posts(array(
            'post_type' => 'sgc_location',
            'post_status' => 'publish',
            'orderby' => 'post_title',
            'sort_order' => 'asc',
            'posts_per_page' => -1
        ));

        // fetch all teams list
        $teams = get_posts(array(
            'post_type' => 'sgc_team',
            'post_status' => 'publish',
            'orderby' => 'post_title',
            'sort_order' => 'asc',
            'posts_per_page' => -1
        ));

        include_once( plugin_dir_path(__FILE__) . '../admin/partials/sgc-admin-events.php' );
    }

    /**
     * 
     */
    public function save_event_meta($post_id) {
        if (array_key_exists('sgc_eventdate', $_POST)) {
            update_post_meta(
                    $post_id, 'sgc_eventdate', $_POST['sgc_eventdate']
            );
        }

        if (array_key_exists('sgc_eventtime', $_POST)) {
            update_post_meta(
                    $post_id, 'sgc_eventtime', $_POST['sgc_eventtime']
            );
        }

        if (array_key_exists('sgc_eventlocation', $_POST)) {
            update_post_meta(
                    $post_id, 'sgc_eventlocation', $_POST['sgc_eventlocation']
            );
        }

        if (array_key_exists('sgc_eventteam', $_POST)) {
            update_post_meta(
                    $post_id, 'sgc_eventteam', $_POST['sgc_eventteam']
            );
        }

        if (array_key_exists('sgc_eventgroups', $_POST)) {
            update_post_meta(
                    $post_id, 'sgc_eventgroups', $_POST['sgc_eventgroups']
            );
        }
        if (array_key_exists('sgc_eventtee', $_POST)) {
            update_post_meta(
                    $post_id, 'sgc_eventtee', $_POST['sgc_eventtee']
            );
        }
    }

}
