<?php

/**
 * Class SGC_Public_Events
 * All methods for public facing event posts
 * 
 * @author Matthew Linton
 *
 */

class SGC_Public_Events {
    /**
     * 
     */
    public static function get_info( $data = [] ) {
        // If we are passed data use that. else use the current post ID
        $event_id = '';
        if( empty( $data) ) {
            $event_id = get_the_id( );
        } elseif ( ! empty( $data['event_id'] ) ) {
            $event_id = $data['event_id'];
        } else {
            return [];
        }
        
        // Fetch our info
        $location = get_post_meta($event_id, 'sgc_eventlocation', true);
        $team = get_post_meta($event_id, 'sgc_eventteam', true);
        
        // get the team name and team post URL
        $team_name = '';
        $team_url = '';
        if ( ! empty( $team ) ) {
            $team_name = get_the_title( $team );
            $team_url = get_the_permalink( $team );
        } 
        
        // get the location name and location post URL and the tees
        $location_name = '';
        $location_url = '';
        if ( ! empty( $location ) ) {
            $location_name = get_the_title( $location );
            $location_url = get_the_permalink( $location );            
        }
        
        return array(
            'date' => get_post_meta($event_id, 'sgc_eventdate', true),
            'time' => get_post_meta($event_id, 'sgc_eventtime', true),
            'team_name' => $team_name,
            'team_url' => $team_url,
            'location' => $location_name,
            'location_url' => $location_url,
            'tee' => get_post_meta($event_id, 'sgc_eventtee', true)
        );
    }
    
    /**
     * 
     */
    public static function get_tees( $data = [] ) {
        // If we are passed data use that. else use the current post ID
        $location = '';
        if( empty( $data ) ) {
            $location = get_post_meta( get_the_id(), 'sgc_eventlocation', true );
        } elseif ( ! empty( $data['event_id'] ) ) {
            $location = get_post_meta( $data['event_id'], 'sgc_eventlocation', true );
        } else {
            return [];
        }
        
        // Exit early if we don't have  a location
        if ( empty( $location ) ) { return []; }
        
        // Return the list of tees
        return json_decode( get_post_meta($location, 'sgc_locationcourse', true ) );
    }
    
    /**
     * 
     */
    public static function get_groups( $data = [] ) {
        // If we are passed data use that. else use the current post ID
        $event_id = '';
        if( empty( $data ) ) {
            $event_id = get_the_id();
        } elseif( ! empty( $data['event_id'] ) ) {
            $event_id = $data['event_id'];
        } else {
            return [];
        }
        
        // exit early if we don't have a event id
        if ( empty( $event_id ) ) { return []; }
        
        // return the list of groups
        return json_decode( get_post_meta($event_id, 'sgc_eventgroups', true) );
    }
    
    /**
     * 
     */
    public static function get_players( $data = [] ) {
        // If we are passed data use that. else use the current post ID
        $event_id = '';
        if( empty( $data['event_id'] ) ) {
            $event_id = get_the_id();
        } elseif ( $data['event_id'] ) {
            $event_id = $data['event_id'];
        } else {
            return [];
        }
        
        // exit early if we don't have an event ID
        if ( empty( $event_id ) ) { return []; }
        
        $team_id = get_post_meta( $event_id, 'sgc_eventteam', true);
        
        // exit early if we don't have a team ID
        if ( empty( $team_id ) ) { return []; }
        
        $players_list = get_posts(array(
            'meta_query' => array(
                array(
                    'key' => 'sgc_playerteam',
                    'value' => $team_id
                )
            ),
            'post_status' => 'publish',
            'post_type' => 'sgc_player',
            'orderby' => 'post_title',
            'order' => 'ASC',
            'posts_per_page' => -1
        ));
        
        // Exit early if we don't have a list of players
        if( empty( $players_list )) { return []; }
        
        // Build the list of players
        $players = [];
        $checkedin_list = json_decode( get_post_meta( $event_id, 'sgc_eventcheckin', true) );
        foreach ($players_list as $player ) {
            $checkedin = 'FALSE';
            if ( $checkedin_list != '' ) {
                foreach( $checkedin_list as $checkedin_id ) {
                    if( $player->ID == $checkedin_id ) {
                        $checkedin = 'TRUE';
                        break;
                    }
                }
            }
            array_push( $players, array( 
                'ID' => $player->ID, 
                'name' => $player->post_title,
                'URL' => get_the_permalink( $player->ID ),
                'checkedin' => $checkedin ) );
        }
        
        return $players;
    }
    
    /**
     * 
     */
    public static function get_scorecards( $data = [] ) {
        // If we are passed data use that. else use the current post ID
        $event_id = '';
        if( empty( $data ) ) {
            $event_id = get_the_id( );
        } elseif( ! empty( $data['event_id'] ) ) {
            $event_id = $data['event_id'];
        } else {
            return [];
        }
        
        // Fetch the list of scorecards
        $scorecards = get_posts(array(
            'meta_query' => array(
                array(
                    'key' => 'sgc_scorecardevent',
                    'value' => get_the_id()
                    )
            ),
            'post_status' => 'publish',
            'post_type' => 'sgc_scorecard',
            'orderby' => 'post_title',
            'order' => 'ASC',
            'posts_per_page' => -1
        ));
        
        // exit early if scorecards is empty
        if ( empty( $scorecards ) ) { return []; }
        
        // Fill the return array with scorecard data
        $player_scores = [];
        foreach( $scorecards as $card ) {
            $player_id = get_post_meta($card->ID, 'sgc_scorecardplayer', true);

            array_push( $player_scores, array(
                'player' => get_the_title( $player_id ),
                'player_url' => get_the_permalink( $player_id ),
                'strokes' => json_decode( get_post_meta($card->ID, 'sgc_scorecardstrokes', true) ),
                'greens' => get_post_meta($card->ID, 'sgc_scorecardgir', true),
                'fairways' => get_post_meta($card->ID, 'sgc_scorecardfh', true),
                'putts' => get_post_meta($card->ID, 'sgc_scorecardputts', true)
            ));
        }
        
        return $player_scores;
    }
    
    /**
     * 
     */
    public function toggle_checkin( $data = [] ) {
        // make sure we have both player and event IDs
        $event_id = '';
        $player_id = '';
        if ( ! empty( $data['event_id'] ) && ! empty( $data['player_id'] ) ) {
            $event_id = $data['event_id'];
            $player_id = $data['player_id'];
        } else {
            return [];
        }
        
        // If either the event or player don't exist, exit early
        if ( FALSE === get_post_status( $event_id ) ) { return []; }
        if ( FALSE === get_post_status( $player_id ) ) { return []; }
        
        // check to see if the player is checked in and remove them
        $checkedin = json_decode(get_post_meta($event_id, 'sgc_eventcheckin', true));
        $ischeckedin = false;
        for ($i = 0; $i < count($checkedin); $i++) {
            if ($checkedin[$i] == $player_id) {
                $ischeckedin = true;
                array_splice($checkedin, $i, 1);
                break;
            }
        }

        // If the player is not checkedin add them
        if ($ischeckedin == false) {
            array_push($checkedin, $player_id);
        }

        //update the Event checkedin array
        update_post_meta($event_id, 'sgc_eventcheckin', json_encode($checkedin));
        
        return array( 
            'event' => $event_id,
            'player' => $player_id,
            'checkedin' => ! $ischeckedin );
    }
    
    /**
     * 
     */
    public function add_rest_events() {
        register_rest_route('simplegolfclub/v1', '/event/info/(?P<event_id>\d+)', array(
            'methods' => 'GET',
            'callback' => array('SGC_Public_Events', 'get_info'),
        ));
        register_rest_route('simplegolfclub/v1', '/event/tees/(?P<event_id>\d+)', array(
            'methods' => 'GET',
            'callback' => array('SGC_Public_Events', 'get_tees'),
        ));
        register_rest_route('simplegolfclub/v1', '/event/groups/(?P<event_id>\d+)', array(
            'methods' => 'GET',
            'callback' => array('SGC_Public_Events', 'get_groups'),
        ));
        register_rest_route('simplegolfclub/v1', '/event/players/(?P<event_id>\d+)', array(
            'methods' => 'GET',
            'callback' => array('SGC_Public_Events', 'get_players'),
        ));
        register_rest_route('simplegolfclub/v1', '/event/scorecards/(?P<event_id>\d+)', array(
            'methods' => 'GET',
            'callback' => array('SGC_Public_Events', 'get_scorecards'),
        ));
        register_rest_route('simplegolfclub/v1', '/event/checkin/(?P<event_id>\d+)/(?P<player_id>\d+)', array(
            'methods' => 'GET',
            'callback' => array('SGC_Public_Events', 'toggle_checkin'),
        ));
    }
}

// #### BEGIN publicaly accessible PHP function wrappers #######################
if (! function_exists( 'sgc_event_getinfo' )) {
    function sgc_event_getinfo( $data = [] ) {
        return SGC_Public_Events::get_info( $data );
    }
}
if (! function_exists( 'sgc_event_gettees' )) {
    function sgc_event_gettees( $data = [] ) {
        return SGC_Public_Events::get_tees( $data );
    }
}
if (! function_exists( 'sgc_event_getgroups' )) {
    function sgc_event_getgroups( $data = [] ) {
        return SGC_Public_Events::get_groups( $data );
    }
}
if (! function_exists( 'sgc_event_getplayers' )) {
    function sgc_event_getplayers( $data = [] ) {
        return SGC_Public_Events::get_players( $data );
    }
}
if (! function_exists( 'sgc_event_getscorecards' )) {
    function sgc_event_getscorecards( $data = [] ) {
        return SGC_Public_Events::get_scorecards( $data );
    }
}
if (! function_exists( 'sgc_event_togglecheckin' )) {
    function sgc_event_togglecheckin( $data = [] ) {
        return SGC_Public_Events::toggle_checkin( $data );
    }
}
