<?php

/**
 * Class SGC_Public_Locationss
 * All methods for public facing location posts
 * 
 * @author Matthew Linton
 *
 */

class SGC_Public_Locations { 
    /**
     * 
     */
    public static function get_info( $data = [] ) {
        // If we are passed data use that. else use the current post ID
        $location_id = '';
        if ( empty( $data ) ) {
            $location_id = get_the_id( );
        } elseif( ! empty( $data['location_id'] ) ) {
            if ( get_post_status( $data['location_id'] ) ) {
                $location_id = $data['location_id'];
            } else {
                return [];
            }
        } else {
            return [];
        }
        
        return array(
            'par' => get_post_meta($location_id, 'sgc_locationpar', true),
            'rating' => get_post_meta($location_id, 'sgc_locationrating', true), 
            'slope' => get_post_meta($location_id, 'sgc_locationslope', true),
        );
    }
    
    /**
     * 
     */
    public function get_tees( $data = [] ) {
        if( empty( $data ) ) {
            return json_decode( get_post_meta( get_the_id(), 'sgc_locationcourse', true) );
        } elseif( ! empty( $data['location_id'] ) ) {
            return json_decode( get_post_meta( $data['location_id'], 'sgc_locationcourse', true) );
        } else {
            return [];
        }
    }
    
    /**
     * 
     */
    public static function get_events ( $data = [] ) {
        // Set up sane defaults
        $location_id = get_the_id();
        $order = 'DESC';      
        $paged = 1;
        $per_page = 5;
        
        // Get passed values if they exist
        if( ! empty( $data ) ) {
            if( ! empty($data['team_id'] ) ) { $location_id = $data['team_id']; }
            if( ! empty($data['order'] ) ) { $order = $data['order']; }
            if( ! empty($data['paged'] ) ) { $paged = $data['paged']; }
            if( ! empty($data['per_page'] ) ) { $per_page = $data['per_page']; }
        }
        
        // fetch event list
        $events = get_posts(array(
            'meta_query' => array(
                array(
                    'key' => 'sgc_eventlocation',
                    'value' => $location_id
                )
            ),
            'post_status' => 'publish',
            'post_type' => 'sgc_event',
            'orderby' => 'post_title',
            'order' => 'ASC',
            'posts_per_page' => -1
        ));
        
        $event_list = [];
        foreach( $events as $event ) {
            array_push( $event_list, array(
                'date' => get_post_meta($event->ID, 'sgc_eventdate', true),
                'time' => get_post_meta($event->ID, 'sgc_eventtime', true),
                'name' => $event->post_title,
                'URL' => get_the_permalink( $event->ID ),
                'tee' => get_post_meta($event->ID, 'sgc_eventtee', true)
            ) );
        }
        return $event_list;
    }
    
    /**
     * 
     */
    public function add_rest_events() {
        register_rest_route('simplegolfclub/v1', '/location/info/(?P<location_id>\d+)', array(
            'methods' => 'GET',
            'callback' => array('SGC_Public_Locations', 'get_info'),
        ));
        register_rest_route('simplegolfclub/v1', '/location/tees/(?P<location_id>\d+)', array(
            'methods' => 'GET',
            'callback' => array('SGC_Public_Locations', 'get_tees'),
        ));
        register_rest_route('simplegolfclub/v1', '/location/events/(?P<location_id>\d+)', array(
            'methods' => 'GET',
            'callback' => array('SGC_Public_Locations', 'get_events'),
        ));
    }
    
}

// #### BEGIN publicaly accessible PHP function wrappers #######################
if (! function_exists( 'sgc_location_getinfo' )) {
    function sgc_location_getinfo( $data = [] ) {
        return SGC_Public_Locations::get_info( $data );
    }
}
if (! function_exists( 'sgc_location_gettees' )) {
    function sgc_location_gettees( $data = [] ) {
        return SGC_Public_Locations::get_tees( $data );
    }
}
if (! function_exists( 'sgc_location_getevents' )) {
    function sgc_location_getevents( $data = [] ) {
        return SGC_Public_Locations::get_events( $data );
    }
}