<?php

/**
 * Class SGC_Public_Players
 * All methods for public facing player posts
 * 
 * @author Matthew Linton
 *
 */

class SGC_Public_Players {
    /**
     *
     */
    public static function get_info( $data = [] ) {
        $team = '';
        $handicap = '';
        $phone = '';
        $email = '';
        $website = '';
        
        if( empty( $data ) ) {
            $team = get_post_meta(get_the_id(), 'sgc_playerteam', true);
            $handicap = get_post_meta(get_the_id(), 'sgc_playerhandicap', true);
            $phone = get_post_meta(get_the_id(), 'sgc_playerphone', true);
            $email = get_post_meta(get_the_id(), 'sgc_playeremail', true);
            $website = get_post_meta(get_the_id(), 'sgc_playerwebsite', true);
        } elseif ( ! empty( $data['player_id'] ) ) {
            $team = get_post_meta($data['player_id'], 'sgc_playerteam', true);
            $handicap = get_post_meta($data['player_id'], 'sgc_playerhandicap', true);
            $phone = get_post_meta($data['player_id'], 'sgc_playerphone', true);
            $email = get_post_meta($data['player_id'], 'sgc_playeremail', true);
            $website = get_post_meta($data['player_id'], 'sgc_playerwebsite', true);
        } else {
            return [];
        }
        
        $team_name = '';
        $team_url = '';
        if ( $team != '' ) {
            $team_name = get_the_title( $team );
            $team_url = get_the_permalink( $team );
        }
        
        return array(
            'team' => $team_name,
            'team_url' => $team_url, 
            'handicap' => $handicap,
            'phone' => $phone,
            'email' => $email,
            'Website' => $website
        );
    }
    
    /**
     * 
     */
    public static function get_scorecards( $data = [] ) {
        // Set up sane defaults
        $player_id = get_the_id();
        $order = 'DESC';      
        $paged = 1;
        $per_page = 5;
        
        // Get passed values if they exist
        if( ! empty( $data ) ) {
            if( ! empty($data['player_id'] ) ) { $player_id = $data['player_id']; }
            if( ! empty($data['order'] ) ) { $order = $data['order']; }
            if( ! empty($data['paged'] ) ) { $paged = $data['paged']; }
            if( ! empty($data['per_page'] ) ) { $per_page = $data['per_page']; }
        }
        
        //Fetch the scorecards for this player
        $scorecards = get_posts(array(
            'meta_query' => array(
                array(
                    'key' => 'sgc_scorecardplayer',
                    'value' => $player_id
                )
            ),
            'post_status' => 'publish',
            'post_type' => 'sgc_scorecard',
            'orderby' => 'post_date',
            'order' => $order,
            'paged' => $paged,
            'posts_per_page' => $per_page
        ));
        
        // Fill the return array with scorecard data
        $player_scores = [];
        foreach( $scorecards as $round ) {
            $event = get_post_meta($round->ID, 'sgc_scorecardevent', true);

            array_push( $player_scores, array(
                'event' => get_the_title( $event ),
                'eventurl' => get_the_permalink( $event ),
                'strokes' => get_post_meta($round->ID, 'sgc_scorecardstrokes', true),
                'greens' => get_post_meta($round->ID, 'sgc_scorecardgir', true),
                'fairways' => get_post_meta($round->ID, 'sgc_scorecardfh', true),
                'putts' => get_post_meta($round->ID, 'sgc_scorecardputts', true)
            ));
        }
        
        return $player_scores;
    }
    
    /**
     *
     */
    public function add_rest_events() {
        register_rest_route('simplegolfclub/v1', '/player/info/(?P<player_id>\d+)', array(
            'methods' => 'GET',
            'callback' => array('SGC_Public_Players', 'get_info'),
        ));
        register_rest_route('simplegolfclub/v1', '/player/scorecards/(?P<player_id>\d+)', array(
            'methods' => 'GET',
            'callback' => array('SGC_Public_Players', 'get_scorecards'),
        ));
        
        // Add player team ID meta field when returning player info
        register_meta( 'post', 'sgc_playerteam', array(
            'type'         => 'integer',
            'description'  => 'Player Team ID',
            'single'       => true,
            'show_in_rest' => true
         ));
    }
    
}

// #### BEGIN publicaly accessible PHP function wrappers #######################
if (! function_exists( 'sgc_player_getinfo' )) {
    function sgc_player_getinfo( $data = [] ) {
        return SGC_Public_Players::get_info( $data );
    }
}
if (! function_exists( 'sgc_player_getscorecards' )) {
    function sgc_player_getscorecards( $data = [] ) {
        return SGC_Public_Players::get_scorecards( $data );
    }
}