<?php

/**
 * Class SGC_Public_Scorecards
 * All methods for public facing location posts
 * 
 * @author Matthew Linton
 *
 */

class SGC_Public_Scorecards { 
    /**
     *
     */
    public static function get_info( $data = [] ) {
        $scorecard_id = '';
        if ( empty( $data ) ) {
            $scorecard_id = get_the_id();
        } elseif( ! empty( $data['scorecard_id'] ) ) {
            $scorecard_id = $data['scorecard_id'];
        } else {
            return [];
        }
        
        // Fetch the event info
        $event_id = get_post_meta( $scorecard_id, 'sgc_scorecardevent', true);
        $event_name = '';
        $event_url = '';
        if ( $event_id != '' ) {
            $event_name = get_the_title( $event_id );
            $event_url = get_the_permalink( $event_id );
        }
        
        // Fetch the player info
        $player_id = get_post_meta($scorecard_id, 'sgc_scorecardplayer', true);
        $player_name = '';
        $player_url = '';
        if ( $player_id != '' ) {
            $player_name = get_the_title( $player_id );
            $player_url = get_the_permalink( $player_id );
        }
        
        return array(
            'event_name' => $event_name,
            'event_url' => $event_url, 
            'player_name' => $player_name,
            'player_url' => $player_url,
            'strokes' => json_decode( get_post_meta( $scorecard_id, 'sgc_scorecardstrokes', true) ),
            'greens' => get_post_meta( $scorecard_id, 'sgc_scorecardgir', true),
            'fairways' => get_post_meta( $scorecard_id, 'sgc_scorecardfh', true),
            'putts' => get_post_meta( $scorecard_id, 'sgc_scorecardputts', true)
        );
    }
    
    /**
     * 
     */
    public function add_rest_events() {
        register_rest_route('simplegolfclub/v1', '/scorecard/info/(?P<scorecard_id>\d+)', array(
            'methods' => 'GET',
            'callback' => array('SGC_Public_Scorecards', 'get_info'),
        ));
    }
}

// #### BEGIN publicaly accessible PHP function wrappers #######################
if (! function_exists( 'sgc_scorecard_getinfo' )) {
    function sgc_scorecard_getinfo( $data = [] ) {
        return SGC_Public_Scorecards::get_info( $data );
    }
}
